@@ -1,5 +1,5 @@
 
-# $Id: Ebay.pm,v 2.254 2010-08-02 01:20:06 Martin Exp $
+# $Id: Ebay.pm,v 2.257 2013-03-02 20:21:17 Martin Exp $
 
 =head1 NAME
 
@@ -156,7 +156,7 @@ use WWW::SearchResult 2.072;
 use WWW::Search::Result;
 
 our
-$VERSION = do { my @r = (q$Revision: 2.254 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.257 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 my $cgi = new CGI;
 
@@ -177,8 +177,14 @@ sub _native_setup_search
 
   $self->{'_next_to_retrieve'} = 0;
   $self->{'_num_hits'} = 0;
-
+  # As of 2013-03-01 (probably much before that, but first time I
+  # looked at it in quite a while): <p>To use our basic experience
+  # which does not require JavaScript, <a
+  # href="http://www.ebay.com/sch/i.html?LH_Auction=1&_nkw=trinidad+tobago+flag&_armrs=1&_from=&_ipg=50&_jsoff=1">click
+  # here</a>.</p>
+  $self->{search_host} ||= 'http://www.ebay.com'; # as of 2013-03-01
   $self->{search_host} ||= 'http://search.ebay.com';
+  $self->{search_path} ||= '/sch/i.html'; # as of 2013-03-01
   $self->{search_path} ||= '/ws/search/SaleSearch';
   if (!defined($self->{_options}))
     {
@@ -199,6 +205,20 @@ sub _native_setup_search
                          # user may have customized (which would come
                          # through via cookies):
                          socustoverride => 1,
+                         # Output basic HTML, not JavaScript:
+                         _armrs => 1,
+                        };
+    $self->{_options} = {
+                         _nkw => $native_query,
+                         _armrs => 1,
+                         # Turn off JavaScript:
+                         _jsoff => 1,
+                         # Search AUCTIONS ONLY:
+                         LH_Auction => 1,
+                         _ipg => $self->{_hits_per_page},
+                         # Which page are we on:
+                         # _from => 2,
+                         # 
                         };
     } # if
   if (defined($rhOptsArg))
@@ -400,6 +420,12 @@ sub _parse_price
     # This item sold, even if it had no bids (i.e. Buy-It-Now)
     $hit->sold(1);
     } # if
+  if (my $oChild = $oTDprice->look_down(_tag => 'div',
+                                        itemprop => 'price'))
+    {
+    # As of 2013-03, we need to separate out the price and the bid:
+    $oTDprice = $oChild;
+    } # if
   my $iPrice = $oTDprice->as_text;
   print STDERR " DDD   raw iPrice ===$iPrice===\n" if  (DEBUG_COLUMNS || (1 < $self->{_debug}));
   $iPrice =~ s!&pound;!GBP!;
@@ -427,6 +453,12 @@ sub _parse_bids
   my $iBids = 0;
   if (ref $oTDbids)
     {
+    if (my $oChild = $oTDbids->look_down(_tag => 'div',
+                                         class => 'bids'))
+      {
+      # As of 2013-03, we need to separate out the price and the bid:
+      $oTDbids = $oChild;
+      } # if
     my $s = $oTDbids->as_HTML;
     if (DEBUG_COLUMNS || (1 < $self->{_debug}))
       {
@@ -506,9 +538,19 @@ sub _parse_enddate
     $sDateTemp = $s = $oTDdate;
     }
   print STDERR " DDD   TDdate ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
+  # New version as of 2013-03:
+  if ($s =~ m/\bTIMEMS="(\d+)"/i)
+    {
+    $sDate = $1;
+    $sDate = $self->_format_date(ParseDate(q{epoch }. int($sDate/1000)));
+    $hit->end_date($sDate);
+    # For backward-compatibility:
+    $hit->change_date($sDate);
+    return 1;
+    }
   if (ref($oTDdate))
     {
-    if ($oTDdate->attr('class') !~ m/\b(ebcTim|ti?me)\b/)
+    if ($oTDdate->attr('class') !~ m/\b(col3|ebcTim|ti?me)\b/)
       {
       # If we see this, we probably were searching for Buy-It-Now items
       # but we ran off the bottom of the item list and ran into the list
@@ -532,7 +574,7 @@ sub _parse_enddate
   $sDateTemp =~ s!<!!;
   # Convert nbsp to regular space:
   $sDateTemp =~ s!\240!\040!g;
-  $sDateTemp =~ s!Time\s+left:!!;
+  $sDateTemp =~ s!Time\s+left:!!g;
   $sDateTemp = $self->_process_date_abbrevs($sDateTemp);
   print STDERR " DDD   cooked sDateTemp ===$sDateTemp===\n" if (DEBUG_DATES || (1 < $self->{_debug}));
   print STDERR " DDD   official time =====$self->{_ebay_official_time}=====\n" if (DEBUG_DATES || (1 < $self->{_debug}));
@@ -632,6 +674,11 @@ sub _get_result_count_elements
                              '_tag' => 'div',
                              class => 'fpc'
                             );
+  push @ao, $tree->look_down(
+                             # For basic search, as of 2013-03:
+                             '_tag' => 'div',
+                             class => 'clt'
+                            );
   push @ao, $tree->look_down(
                             '_tag' => 'div',
                             class => 'count'
@@ -812,7 +859,7 @@ sub _parse_tree
     # use File::Slurp;
     # write_file('no-results.html', $self->{response}->content);
     } # unless
-  my $qrItemNum = qr{(?:[;Q]item[=Z]|/)(\d{12})(?:[;Q]|\?cmd)};
+  my $qrItemNum = qr{(\d{11,13})};
  TD:
   foreach my $oTDtitle (@aoTD)
     {
@@ -828,7 +875,7 @@ sub _parse_tree
     next TD if ($sTitle eq '');
     print STDERR " DDD   sTitle ===$sTitle===\n" if (1 < $self->{_debug});
     my $oURI = URI->new($oA->attr('href'));
-    next TD unless ($oURI =~ m!ViewItem!);
+    # next TD unless ($oURI =~ m!ViewItem!);
     next TD unless ($oURI =~ m!$qrItemNum!);
     my $iItemNum = $1;
     my $iCategory = -1;
@@ -881,13 +928,15 @@ sub _parse_tree
       next unless ref($oTDsib);
       my $s = $oTDsib->as_HTML;
       print STDERR " DDD   try TD'$sColumn' ===$s===\n" if (DEBUG_COLUMNS || (1 < $self->{_debug}));
-      if ($sColumn eq 'price')
+      if ($sColumn =~ m'price')
         {
         next TD unless $self->_parse_price($oTDsib, $hit);
-        }
-      elsif ($sColumn eq 'bids')
+        } # if
+      # As of 2013-03, price and bids are in the same cell, so don't
+      # make this an elsif:
+      if ($sColumn =~ m'bids')
         {
-        next TD unless $self->_parse_bids($oTDsib, $hit);
+        $self->_parse_bids($oTDsib, $hit);
         }
       elsif ($sColumn eq 'shipping')
         {
@@ -919,7 +968,7 @@ sub _parse_tree
         }
       else
         {
-        print STDERR " DDD     do not know how to handle column named $sColumn\n" if (1 < $self->{_debug});
+        # print STDERR " DDD     do not know how to handle column named $sColumn\n" if (1 < $self->{_debug});
         next SIBLING_TD;
         }
       } # while
@@ -940,6 +989,7 @@ sub _parse_tree
       # Item must have been sold!?!
       $hit->sold(1);
       } # if
+    print STDERR " DDD   add hit to cache\n" if (1 < $self->{_debug});
     push(@{$self->{cache}}, $hit);
     $self->{'_num_hits'}++;
     $iHits++;
@@ -1124,7 +1174,7 @@ Include parentheses so that $1 becomes the number (with commas is OK).
 
 sub _result_count_pattern
   {
-  return qr'([0-9,]+) (item|match|result)e?s? found\b';
+  return qr'([0-9,]+)\s+(active\s+)?(listing|item|matche?|result)s?(\s+found)?\b';
   } # _result_count_pattern
 
 
@@ -1138,7 +1188,7 @@ sub _columns
   {
   my $self = shift;
   # This is for basic USA eBay:
-  return qw( paypal bids price enddate );
+  return qw( enddate pricebids );
   } # _columns
 
 1;
